@@ -4,7 +4,7 @@ package Data::Record::Serialize::Role::Base;
 
 use Moo::Role;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use Data::Record::Serialize::Error { errors => [ 'fields' ] }, -all;
 
@@ -424,30 +424,37 @@ has _map_types => (
 
 #pod =attr C<format_fields>
 #pod
-#pod A hash mapping the input field names to a C<sprintf> style
-#pod format. This will be applied prior to encoding the record, but only if
-#pod the C<format> attribute is also set.  Formats specified here override
-#pod those specified in C<format_types>.
+#pod A hash mapping the input field names to either a C<sprintf> style
+#pod format or a coderef. This will be applied prior to encoding the
+#pod record, but only if the C<format> attribute is also set.  Formats
+#pod specified here override those specified in C<format_types>.
+#pod
+#pod The coderef will be called with the value to format as its first
+#pod argument, and should return the formatted value.
 #pod
 #pod =cut
 
 has format_fields => (
     is  => 'ro',
-    isa => HashRef [Str],
+    isa => HashRef [Str | CodeRef],
 );
 
 #pod =attr C<format_types>
 #pod
 #pod A hash mapping a field type (C<N>, C<I>, C<S>) to a C<sprintf> style
-#pod format.  This will be applied prior to encoding the record, but only
-#pod if the C<format> attribute is also set.  Formats specified here may be
-#pod overridden for specific fields using the C<format_fields> attribute.
+#pod format or a coderef.  This will be applied prior to encoding the
+#pod record, but only if the C<format> attribute is also set.  Formats
+#pod specified here may be overridden for specific fields using the
+#pod C<format_fields> attribute.
+#pod
+#pod The coderef will be called with the value to format as its first
+#pod argument, and should return the formatted value.
 #pod
 #pod =cut
 
 has format_types => (
     is  => 'ro',
-    isa => HashRef [Str],
+    isa => HashRef [Str | CodeRef],
     # we'll need to gather types
     trigger => sub { $_[0]->_set__need_types( 1 ) if keys %{ $_[1] }; },
 );
@@ -661,7 +668,7 @@ Data::Record::Serialize::Role::Base - Base Role for Data::Record::Serialize
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 DESCRIPTION
 
@@ -835,17 +842,24 @@ is called), so there is no immediate feedback.
 
 =head2 C<format_fields>
 
-A hash mapping the input field names to a C<sprintf> style
-format. This will be applied prior to encoding the record, but only if
-the C<format> attribute is also set.  Formats specified here override
-those specified in C<format_types>.
+A hash mapping the input field names to either a C<sprintf> style
+format or a coderef. This will be applied prior to encoding the
+record, but only if the C<format> attribute is also set.  Formats
+specified here override those specified in C<format_types>.
+
+The coderef will be called with the value to format as its first
+argument, and should return the formatted value.
 
 =head2 C<format_types>
 
 A hash mapping a field type (C<N>, C<I>, C<S>) to a C<sprintf> style
-format.  This will be applied prior to encoding the record, but only
-if the C<format> attribute is also set.  Formats specified here may be
-overridden for specific fields using the C<format_fields> attribute.
+format or a coderef.  This will be applied prior to encoding the
+record, but only if the C<format> attribute is also set.  Formats
+specified here may be overridden for specific fields using the
+C<format_fields> attribute.
+
+The coderef will be called with the value to format as its first
+argument, and should return the formatted value.
 
 =head2 C<rename_fields>
 
@@ -859,10 +873,21 @@ C<format_fields> and/or C<format_types> options.  The default is false.
 
 =for Pod::Coverage BUILD
 
-=head1 BUGS AND LIMITATIONS
+=head1 SUPPORT
 
-You can make new bug reports, and view existing ones, through the
-web interface at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize>.
+=head2 Bugs
+
+Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/data-record-serialize
+
+and may be cloned from
+
+  https://gitlab.com/djerius/data-record-serialize.git
 
 =head1 SEE ALSO
 
