@@ -4,9 +4,10 @@ package Data::Record::Serialize::Role::Default;
 
 use Moo::Role;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use Hash::Util qw[ hv_store ];
+use Ref::Util qw[ is_coderef ];
 
 use namespace::clean;
 
@@ -83,18 +84,20 @@ before 'send' => sub {
 
     # nullify fields (set to undef) those that are zero length
 
-    if ( defined ( my $nullify = $self->_nullify ) ) {
+    if ( defined( my $nullify = $self->_nullify ) ) {
 
         $data->{$_} = undef
-          for grep { defined $data->{$_} && ! length $data->{$_} }
-          @$nullify;
+          for grep { defined $data->{$_} && !length $data->{$_} } @$nullify;
     }
 
     if ( $self->_format ) {
 
         my $format = $self->_format;
 
-        $data->{$_} = sprintf( $format->{$_}, $data->{$_} )
+        $data->{$_}
+          = is_coderef( $format->{$_} )
+          ? $format->{$_}( $data->{$_} )
+          : sprintf( $format->{$_}, $data->{$_} )
           foreach grep { defined $data->{$_} && length $data->{$_} }
           keys %{$format};
     }
@@ -151,7 +154,7 @@ Data::Record::Serialize::Role::Default - Default methods for Data::Record::Seria
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 DESCRIPTION
 
@@ -175,10 +178,21 @@ contents, pass in a copy.
  setup
  DEMOLISH
 
-=head1 BUGS AND LIMITATIONS
+=head1 SUPPORT
 
-You can make new bug reports, and view existing ones, through the
-web interface at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize>.
+=head2 Bugs
+
+Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize
+
+=head2 Source
+
+Source is available at
+
+  https://gitlab.com/djerius/data-record-serialize
+
+and may be cloned from
+
+  https://gitlab.com/djerius/data-record-serialize.git
 
 =head1 SEE ALSO
 
